@@ -24,13 +24,13 @@
 #include <config.h>
 #endif
 
+#include <glib/gi18n.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkwidget.h>
 #include <bonobo/bonobo-context.h>
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-generic-factory.h>
 #include <bonobo/bonobo-main.h>
-#include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-program.h>
 #include <libgnomeui/gnome-ui-init.h>
 #include <libgnomevfs/gnome-vfs.h>
@@ -115,7 +115,7 @@ main_base_factory (BonoboGenericFactory *factory,
 }
 
 static CORBA_Object
-main_activate_base ()
+main_activate_base (void)
 {
 	CORBA_Environment ev;
 	CORBA_Object      yelp_base;
@@ -312,8 +312,7 @@ main (int argc, char **argv)
 	GnomeClient   *client;
 	gboolean       session_started = FALSE;
 	const gchar  **args;
-	
-	
+
 	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);  
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
