@@ -25,7 +25,7 @@
 #endif
 
 #include <glib.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libxml/parser.h>
 #include <libxml/parserInternals.h>
 #include <libxslt/xslt.h>
@@ -40,8 +40,8 @@
 #include "yelp-man-parser.h"
 #include "yelp-settings.h"
 
-#define MAN_STYLESHEET_PATH DATADIR"/sgml/docbook/yelp/"
-#define MAN_STYLESHEET      MAN_STYLESHEET_PATH"man2html.xsl"
+#define STYLESHEET_PATH DATADIR"/yelp/xslt/"
+#define MAN_STYLESHEET  STYLESHEET_PATH"man2html.xsl"
 
 struct _YelpManPagerPriv {
     gpointer unused;
@@ -182,7 +182,7 @@ man_pager_params (YelpPager *pager)
     params = g_new0 (gchar *, params_max);
 
     params[params_i++] = "stylesheet_path";
-    params[params_i++] = g_strdup_printf ("\"file://%s\"", MAN_STYLESHEET_PATH);
+    params[params_i++] = g_strdup_printf ("\"file://%s\"", STYLESHEET_PATH);
 
     params[params_i] = NULL;
 
