@@ -54,8 +54,8 @@
 
 #define YELP_NAMESPACE "http://www.gnome.org/yelp/ns"
 
-#define TOC_STYLESHEET_PATH DATADIR"/sgml/docbook/yelp/"
-#define TOC_STYLESHEET      TOC_STYLESHEET_PATH"toc2html.xsl"
+#define STYLESHEET_PATH DATADIR"/yelp/xslt/"
+#define TOC_STYLESHEET  STYLESHEET_PATH"toc2html.xsl"
 
 typedef gboolean      (*ProcessFunction)        (YelpTocPager      *pager);
 
@@ -365,7 +365,7 @@ toc_process_pending (YelpTocPager *pager)
     static gint process_i = 0;
 
     if (priv->cancel || !priv->pending_func) {
-	// FIXME: clean stuff up.
+	/* FIXME: clean stuff up. */
 	return FALSE;
     }
 
@@ -537,6 +537,8 @@ process_omf_pending (YelpTocPager *pager)
 	xmlXPathFreeObject (omf_description);
     if (omf_category)
 	xmlXPathFreeObject (omf_category);
+    if (omf_language)
+	xmlXPathFreeObject (omf_language);
     if (omf_seriesid)
 	xmlXPathFreeObject (omf_seriesid);
 
@@ -775,9 +777,9 @@ process_read_menu (YelpTocPager *pager)
     for (i = 0; i < obj->nodesetval->nodeNr; i++) {
 	xmlNodePtr node = obj->nodesetval->nodeTab[i];
 	xmlChar *icon = NULL;
-	xmlChar *id = NULL;
 
 #ifdef ENABLE_MAN
+	xmlChar *id = NULL;
 	id = xmlGetProp (node, "id");
 	if (!xmlStrcmp (id, "index")) {
 	    xmlNodePtr new = xmlNewChild (node, NULL, "toc", NULL);
@@ -800,6 +802,7 @@ process_read_menu (YelpTocPager *pager)
 		gtk_icon_info_free (info);
 	    }
 	}
+	xmlFree (icon);
 
     }
     xmlXPathFreeObject (obj);
@@ -823,6 +826,8 @@ process_read_menu (YelpTocPager *pager)
 
 	    xpath_s = g_strdup_printf ("//toc[@id = '%s']", id);
 	    obj = xmlXPathEvalExpression (xpath_s, xpath);
+	    g_free (xpath_s);
+
 	    node = obj->nodesetval->nodeTab[0];
 	    xmlXPathFreeObject (obj);
 
@@ -861,7 +866,7 @@ process_xslt (YelpTocPager *pager)
     GError *error = NULL;
     xmlDocPtr outdoc;
     YelpTocPagerPriv *priv = pager->priv;
-    const gchar **params;
+    gchar **params;
     gint  params_i = 0;
     gint  params_max = 10;
     GtkIconInfo *info;
@@ -894,7 +899,7 @@ process_xslt (YelpTocPager *pager)
 	params = g_renew (gchar *, params, params_max);
     }
 
-    info = gtk_icon_theme_lookup_icon (theme, "gnome-help", 192, 0);
+    info = gtk_icon_theme_lookup_icon (theme, "yelp-icon-big", 192, 0);
     if (info) {
 	params[params_i++] = "help_icon";
 	params[params_i++] = g_strdup_printf ("\"%s\"",
@@ -909,7 +914,7 @@ process_xslt (YelpTocPager *pager)
 
     outdoc = xsltApplyStylesheetUser (priv->stylesheet,
 				      priv->toc_doc,
-				      params, NULL, NULL,
+				      (const gchar **)params, NULL, NULL,
 				      priv->transformContext);
     g_signal_emit_by_name (pager, "finish");
 
@@ -1053,7 +1058,7 @@ xslt_yelp_document (xsltTransformContextPtr ctxt,
 
     xsltApplyOneTemplate (ctxt, node, inst->children, NULL, NULL);
 
-    htmlDocDumpMemory (new_doc, &page_buf, &buf_size);
+    xsltSaveResultToString (&page_buf, &buf_size, new_doc, style);
 
     ctxt->outputFile = old_outfile;
     ctxt->output     = old_doc;
