@@ -26,12 +26,12 @@
 #include <config.h>
 #endif
 
+#include <glib/gi18n.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
 #include <bonobo/bonobo-main.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomeui/gnome-stock-icons.h>
-#include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-url.h>
 #include <libgnome/gnome-program.h>
 #include <libgnome/gnome-config.h>
@@ -197,14 +197,8 @@ static void               location_response_cb    (GtkDialog       *dialog,
 						   gint             id,
 						   YelpWindow      *window);
 
-static void        window_find_again_cb           (gpointer           data,
-						   guint              action,
-						   GtkWidget         *widget);
 static gboolean    window_find_action             (YelpWindow        *window, 
 						   YelpFindAction     action);
-static gboolean    window_find_delete_event_cb    (GtkWidget         *widget,
-						   GdkEvent          *event,
- 			                           gpointer           data);
 static void        window_find_entry_changed_cb   (GtkEditable       *editable,
 						   gpointer           data);
 static void        window_find_save_settings      (YelpWindow        *window);
@@ -294,11 +288,7 @@ enum {
     TARGET_URI_LIST
 };
 
-static GtkTargetEntry row_targets[] = {
-    { TARGET_TYPE_URI_LIST, 0, TARGET_URI_LIST }
-};
-
-static GtkActionEntry entries[] = {
+static const GtkActionEntry entries[] = {
     { "FileMenu",      NULL, N_("_File")      },
     { "EditMenu",      NULL, N_("_Edit")      },
     { "GoMenu",        NULL, N_("_Go")        },
@@ -738,7 +728,6 @@ yelp_window_load (YelpWindow *window, const gchar *uri)
  load:
     window_do_load (window, doc_info, frag_id);
 
- done:
     if (priv->current_frag != frag_id)
 	g_free (frag_id);
 }
@@ -807,6 +796,7 @@ window_do_load (YelpWindow  *window,
 		       "the author of the document to convert to XML."));
 	break;
     case YELP_DOC_TYPE_HTML:
+    case YELP_DOC_TYPE_XHTML:
 	handled = window_do_load_html (window, doc_info, frag_id);
 	break;
     case YELP_DOC_TYPE_EXTERNAL:
@@ -930,7 +920,7 @@ window_populate (YelpWindow *window)
 
     priv->pane = gtk_hpaned_new ();
     gtk_widget_ref (priv->pane);
-    // We should probably remember the last position and set to that.
+    /* We should probably remember the last position and set to that. */
     gtk_paned_set_position (GTK_PANED (priv->pane), 180);
 
     priv->side_sw = gtk_scrolled_window_new (NULL, NULL);
@@ -1022,12 +1012,12 @@ window_populate_find (YelpWindow *window, GtkWidget *find_bar)
 
     box = gtk_hbox_new (FALSE, 0);
     label = gtk_label_new_with_mnemonic (_("Find:"));
-    gtk_box_pack_start (box, label, FALSE, FALSE, 6);
+    gtk_box_pack_start (GTK_BOX (box), label, FALSE, FALSE, 6);
 
     priv->find_entry = gtk_entry_new ();
     g_signal_connect (G_OBJECT (priv->find_entry), "changed",
 		      G_CALLBACK (window_find_entry_changed_cb), window);
-    gtk_box_pack_start (box, priv->find_entry, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (box), priv->find_entry, TRUE, TRUE, 0);
 
     item = gtk_tool_item_new ();
     gtk_container_add (GTK_CONTAINER (item), box);
@@ -1199,7 +1189,7 @@ window_do_load_pager (YelpWindow  *window,
     case YELP_PAGER_STATE_NEW:
     case YELP_PAGER_STATE_INVALID:
 	startnow = TRUE;
-	// no break
+	/* no break */
     case YELP_PAGER_STATE_STARTED:
     case YELP_PAGER_STATE_PARSING:
 	priv->start_handler =
@@ -1251,7 +1241,7 @@ window_do_load_pager (YelpWindow  *window,
 	    }
 	}
 
-	// FIXME: error if !handled
+	/* FIXME: error if !handled */
     }
 
  done:
@@ -1298,7 +1288,7 @@ window_do_load_html (YelpWindow    *window,
 
     if (result != GNOME_VFS_OK) {
 	GError *error = NULL;
-	g_set_error (error, YELP_ERROR, YELP_ERROR_IO,
+	g_set_error (&error, YELP_ERROR, YELP_ERROR_IO,
 		     _("The file ‘%s’ could not be read.  This file might "
 		       "be missing, or you might not have permissions to "
 		       "read it."),
@@ -1309,7 +1299,17 @@ window_do_load_html (YelpWindow    *window,
     }
 
     yelp_html_set_base_uri (priv->html_view, uri);
-    yelp_html_clear (priv->html_view);
+
+    switch (yelp_doc_info_get_type (doc_info)) {
+    case YELP_DOC_TYPE_HTML:
+	yelp_html_open_stream (priv->html_view, "text/html");
+	break;
+    case YELP_DOC_TYPE_XHTML:
+	yelp_html_open_stream (priv->html_view, "application/xhtml+xml");
+	break;
+    default:
+	g_assert_not_reached ();
+    }
 
     while ((result = gnome_vfs_read
 	    (handle, buffer, BUFFER_SIZE, &n)) == GNOME_VFS_OK) {
@@ -1442,14 +1442,14 @@ window_handle_page (YelpWindow   *window,
 		      "sensitive",
 		      priv->prev_id ? TRUE : FALSE,
 		      NULL);
-    priv->prev_id = page->prev_id;
+    priv->next_id = page->next_id;
     action = gtk_action_group_get_action (priv->action_group, "GoNext");
     if (action)
 	g_object_set (G_OBJECT (action),
 		      "sensitive",
 		      priv->next_id ? TRUE : FALSE,
 		      NULL);
-    priv->prev_id = page->prev_id;
+    priv->toc_id = page->toc_id;
     action = gtk_action_group_get_action (priv->action_group, "GoContents");
     if (action)
 	g_object_set (G_OBJECT (action),
@@ -1470,7 +1470,7 @@ window_handle_page (YelpWindow   *window,
     d (g_print ("  uri            = %s\n", uri));
 
     yelp_html_set_base_uri (priv->html_view, uri);
-    yelp_html_clear (priv->html_view);
+    yelp_html_open_stream (priv->html_view, "application/xhtml+xml");
 
     priv->idle_write = gtk_idle_add ((GtkFunction) idle_write, context);
 
@@ -1672,7 +1672,7 @@ pager_finish_cb (YelpPager   *pager,
 		 window->priv->current_frag);
     window_error (window, error, TRUE);
 
-    // FIXME: Remove the URI from the history and go back
+    /* FIXME: Remove the URI from the history and go back */
 }
 
 /** Gecko Callbacks ***********************************************************/
@@ -1929,7 +1929,7 @@ window_find_cb (GtkAction *action, YelpWindow *window)
 
     gtk_widget_show_all (priv->find_bar);
     gtk_widget_grab_focus (priv->find_entry);
-    window_find_entry_changed_cb (priv->find_entry, window);
+    window_find_entry_changed_cb (GTK_EDITABLE (priv->find_entry), window);
 }
 
 static void
@@ -2154,7 +2154,7 @@ window_about_cb (GtkAction *action, YelpWindow *window)
 {
     const gchar *copyright =
 	"Copyright © 2001-2003 Mikael Hallendal\n"
-	"Copyright © 2003-2004 Shaun McCance";
+	"Copyright © 2003-2005 Shaun McCance";
     const gchar *authors[] = { 
 	"Mikael Hallendal <micke@imendio.com>",
 	"Alexander Larsson <alexl@redhat.com>",
@@ -2162,7 +2162,7 @@ window_about_cb (GtkAction *action, YelpWindow *window)
 	NULL
     };
     /* Note to translators: put here your name (and address) so it
-     * will shop up in the "about" box */
+     * will show up in the "about" box */
     const gchar *translator_credits = _("translator-credits");
 
     gtk_show_about_dialog (GTK_WINDOW (window),
@@ -2231,20 +2231,6 @@ window_find_action (YelpWindow *window, YelpFindAction action)
 			   (action == YELP_WINDOW_FIND_NEXT) ? TRUE: FALSE);
 }
 
-static void 
-window_find_again_cb (gpointer   data,
-                      guint      action,
-		      GtkWidget *widget)
-{
-    YelpWindow *window;
-
-    g_return_if_fail (YELP_IS_WINDOW (data));
- 
-    window = YELP_WINDOW (data);
-
-    window_find_action (window, (YelpFindAction)action);
-}
-
 static void
 window_find_clicked_cb (GtkWidget  *widget,
 			YelpWindow *window)
@@ -2303,38 +2289,6 @@ window_find_entry_changed_cb (GtkEditable *editable,
     g_free (text);
 }
 
-static void
-window_find_case_toggled_cb (GtkWidget *widget,
-			     gpointer   data)
-{
-    YelpWindow     *window;
-    YelpWindowPriv *priv;
-
-    g_return_if_fail (YELP_IS_WINDOW (data));
-
-    window = YELP_WINDOW (data);
-    priv   = window->priv;
-
-    window_find_entry_changed_cb (GTK_EDITABLE (priv->find_entry),
-				  window);
-}
-
-static void
-window_find_wrap_toggled_cb (GtkWidget *widget,
-			     gpointer   data)
-{
-    YelpWindow     *window;
-    YelpWindowPriv *priv;
-
-    g_return_if_fail (YELP_IS_WINDOW (data));
-
-    window = YELP_WINDOW (data);
-    priv   = window->priv;
-
-    window_find_entry_changed_cb (GTK_EDITABLE (priv->find_entry),
-				  window);
-}
-
 static void
 window_find_buttons_set_sensitive (YelpWindow *window,
 				   gboolean    sensitive)
